@@ -97,7 +97,6 @@ namespace log4shib {
         Properties::const_iterator to = _properties.lower_bound(prefix + '/');
         for(Properties::const_iterator i = from; i != to; ++i) {
             const std::string& key = (*i).first;
-            const std::string& value = (*i).second;
             std::list<std::string> propNameParts;
             std::back_insert_iterator<std::list<std::string> > pnpIt(propNameParts);
             StringUtil::split(pnpIt, key, '.');
@@ -171,6 +170,11 @@ namespace log4shib {
         bool additive = _properties.getBool("additivity." + categoryName, true);
         category.setAdditivity(additive);
 
+        // Hack to assign ownership of related Appenders to this Category
+        // Defaults to true for rootCategory, false otherwise.
+        bool ownAppenders = _properties.getBool("ownAppenders." + categoryName,
+            categoryName == "rootCategory");
+
         category.removeAllAppenders();
         for(/**/; i != iEnd; ++i) {           
             std::string appenderName = StringUtil::trim(*i);
@@ -180,7 +184,7 @@ namespace log4shib {
                 // appender not found;
                 throw ConfigureFailure(std::string("Appender '") +
                     appenderName + "' not found for category '" + categoryName + "'");
-            } else if (categoryName == "rootCategory") {
+            } else if (ownAppenders) {
 
                 /* pass by pointer, i.e. transfer ownership */
                 category.addAppender((*appIt).second);
@@ -222,7 +226,7 @@ namespace log4shib {
             appender = new RollingFileAppender(appenderName, fileName, maxFileSize, maxBackupIndex,
                 append);
         }
-        else if (appenderType == "SyslogAppender") {
+        else if (appenderType == "SyslogAppender" || appenderType == "RemoteSyslogAppender") {
             std::string syslogName = _properties.getString(appenderPrefix + ".syslogName", "syslog");
             std::string syslogHost = _properties.getString(appenderPrefix + ".syslogHost", "localhost");
             int facility = _properties.getInt(appenderPrefix + ".facility", -1) * 8; // * 8 to get LOG_KERN, etc. compatible values. 
@@ -337,14 +341,21 @@ namespace log4shib {
         categories.clear();
 
         // add the root category first
+        std::set<std::string> contents;
         categories.push_back(std::string("rootCategory"));
+        contents.insert(std::string("rootCategory"));
 
         // then look for "category."
         std::string prefix("category");
         Properties::const_iterator from = _properties.lower_bound(prefix + '.');
         Properties::const_iterator to = _properties.lower_bound(prefix + (char)('.' + 1)); 
         for (Properties::const_iterator iter = from; iter != to; iter++) {
-            categories.push_back((*iter).first.substr(prefix.size() + 1));
+            std::string what((*iter).first.substr(prefix.size() + 1));
+            bool is_in = (contents.find(what) != contents.end());
+            if ("" != what && !is_in) {
+                categories.push_back(what);
+                contents.insert(what);
+            }
         }
     }
 }
